#![deny(missing_docs)]

//! # Game Skunk Advance
//! Game development library modelled after an imaginary console
//!
//! ## Specs
//! - Resolution: 304x176 (19x11 tiles)
//! - Colors: 256 (indexed out of a possible 24-bit)
//! - Tilesize: 16x16 (or 8x8 for half-tiles)
//! - Tileset: 65536 tiles, indexed via 0xYYXX
//! - Sprites: 256 of size 16x16 (pondering allowing larger sprites)
//! - Tilemaps: 4 of size 1024x1024, scrollable
//!
//! ## Features not yet implemented
//! - Sound (no samples
//!   - Synth
//!   - Speech
//! - Savegames
//! - Helpers
//!   - Gamepad text keyboard input
//!   - Menus

mod buttons;
mod gsa;
mod input;
mod rgb;
mod run;
mod sprite;
mod state;
mod tilemap;

pub use crate::buttons::Buttons;
pub use crate::gsa::Gsa;
pub use crate::input::Input;
pub use crate::rgb::Rgb;
pub use crate::run::run;
pub use crate::sprite::Sprite;
pub use crate::tilemap::Tilemap;

/// Amount of sprites in [Gsa::sprites]
pub const MAX_SPRITES: usize = 0xff;

/// X and y dimensions of maps in [Gsa::maps]
pub const TILEMAP_MAX_SIZE: usize = 1024;

/// Amount of tile maps in [Gsa::maps]
pub const MAX_TILEMAPS: usize = 4;
